﻿import util.Observer;
import util.Observable;
import logger.Logger;
import logger.LogMessage;

/**
 * Logger類別的一個觀察者。這個類別 
 * 將在文字欄位顯示傳給log的訊息。
 */
class logger.TextFieldView implements Observer {
  // 這個物件所觀察的log
  private var log:Logger;
  // 文字欄位的參考
  private var out:TextField;

  /**
   * TextFieldView建構子
   */
  public function TextFieldView (l:Logger,
                                 target:MovieClip, 
                                 depth:Number, 
                                 x:Number,
                                 y:Number,
                                 w:Number,
                                 h:Number) {
    log = l;
    makeTextField(target, depth, x, y, w, h);
  }

  /**
   * 當log改變時，呼叫這個方法。詳細的說明， 
   * 請參閱範例16-2的Observer介面。
   */
  public function update (o:Observable, infoObj:Object):Void {
    // 為了類型檢驗，把infoObj轉換成LogMessage實體。
    var logMsg:LogMessage = LogMessage(infoObj);
    // 在文字欄位顯示日誌訊息 
    out.text += Logger.getLevelDesc(logMsg.getLevel(  )) 
             + ": " + logMsg.getMessage(  )  + "\n";
    // 把文字欄位捲到最底下
    out.scroll = out.maxscroll;
  }

  /**
   * 在指定的影片片段裡的特定深度，建立文字欄位。 
   * 日誌訊息將顯示在這個文字欄位裡面。
   */
  public function makeTextField (target:MovieClip, 
                              depth:Number,
                              x:Number,
                              y:Number,
                              w:Number,
                              h:Number):Void {
    // 建立文字欄位
    target.createTextField("log_txt", depth, x, y, w, h);
    //儲存這個欄位的參考
    out = target.log_txt;
    // 顯示文字欄位的邊框
    out.border = true;
    // 讓文字欄位裡的文字自動換行
    out.wordWrap = true;
  }

  public function destroy (  ):Void {
    log.removeObserver(this);
    out.removeTextField(  );
  }
}